package composite;

import java.util.Collection;

/**
 * The interface for the Composite Pattern
 */
public interface Component {
	// specific methods for the context in which this pattern is applied 
	public double getPrice(); 
	public double getWeight();
	public double getAmps();
	

	// the Composite Pattern methods that both Composites and Parts must implement
	/**
	 * adds a Component to the collection
	 * @param c component to be added
	 * @return true if successful
	 */ 
	public boolean add(Component c);
	
	/**
	 * removes a component from the collection
	 * @param c component to be removed
	 * @return true if successful
	 */
	public boolean remove(Component c);
	
	/**
	 * retrieves a collection of components contained by this component
	 * @return the collection of children
	 */
	public Collection<Component> getChildren();
}
